pub struct History {
pub id: i64,
pub client_id: String,
pub user_id: i64,
pub hostname: String,
pub timestamp: OffsetDateTime,
pub data: String,
pub created_at: OffsetDateTime,
}Fields
id: i64client_id: Stringuser_id: i64hostname: Stringtimestamp: OffsetDateTimedata: StringAll the data we have about this command, encrypted.
Currently this is an encrypted msgpack object, but this may change in the future.
created_at: OffsetDateTimeAuto Trait Implementations
impl Freeze for History
impl RefUnwindSafe for History
impl Send for History
impl Sync for History
impl Unpin for History
impl UnsafeUnpin for History
impl UnwindSafe for History